<?php

class Bootstrap extends Zend_Application_Bootstrap_Bootstrap
{
    /**
     * @var int
     */
    const DEFAULT_RECORDS_PER_PAGE = 10;

    /**
     *  Instantiate the application database resource object
     *
     *  @return Zend_Db_Adapter
     *  @link http://framework.zend.com/manual/en/zend.db.html
     */
    protected function _initDb()
    {
        /**
         * Boot the cache initialisation for use her.
         */
        $this->bootstrap('Cache');
        $this->_cache = $this->getResource('Cache');

        /**
         * Only attempt to cache the metadata if we have a cache available
         */
        if (!is_null($this->_cache)) {
            try {
                Zend_Db_Table_Abstract::setDefaultMetadataCache($this->_cache);
            } catch(Zend_Db_Table_Exception $e) {
                print $e->getMessage();
            }
        }

        $db = $this->getPluginResource('db')->getDbAdapter();

        /**
         * Set the default fetch mode to object throughout the application
         */
        $db->setFetchMode(Zend_Db::FETCH_OBJ);

        /**
         * Force the initial connection to handle error relating to caching etc.
         */
        try {
            $db->getConnection();
        } catch (Zend_Db_Adapter_Exception $e) {
            // perhaps a failed login credential, or perhaps the RDBMS is not running
        } catch (Zend_Exception $e) {
            // perhaps factory() failed to load the specified Adapter class
        }

        Zend_Db_Table::setDefaultAdapter($db);
        Zend_Registry::set('db', $db);

        return $db;
    }
    
    protected function getConfig($option) 
    {
        return (object)$this->getOption($option);
    } 
    
    /**
     * Setup the application cache.
     *
     * @return Zend_Cache
     * @link http://framework.zend.com/manual/en/zend.cache.html
     */
    protected function _initCache()
    {
        $this->bootstrap('Config');
        $appConfig = Zend_Registry::get('config');
        $cache = NULL;

        // only attempt to init the cache if turned on
        if ($appConfig->app->caching) {
            // get the cache settings
            $config = $appConfig->app->cache;

            if (NULL !== $this->_tmpFolder) {
                if ('File' == $config->backend->adapter && !isset($config->backend->options->cache_dir)) {
                    $config->backend->options->cache_dir = $this->_tmpFolder . '/cache';
                    if (!is_dir($config->backend->options->cache_dir)) {
                        mkdir($config->backend->options->cache_dir);
                    }
                }
            }

            try {
                $cache = Zend_Cache::factory(
                        $config->frontend->adapter,
                        $config->backend->adapter,
                        $config->frontend->options->toArray(),
                        $config->backend->options->toArray()
                );
            } catch (Zend_Cache_Exception $e) {
                // send email to alert caching failed
                Zend_Registry::get('log')->alert(
                        'Caching failed: adapter=' . $config->backend->adapter . ', message=' . $e->getMessage(
                ));
            }
        }
        Zend_Registry::set('cache', $cache);
        return $cache;
    }
    
    protected function _initServices()
    {
        return null;
    }

    /**
     * Setup the core config resource
     *
     * @return Zend_Config_Ini
     * @link http://framework.zend.com/manual/en/zend.config.html
     */
    protected function _initConfig()
    {
        $config = new Zend_Config_Ini(
            APPLICATION_PATH . "/configs/application.ini",
            $this->getEnvironment()
        );
        Zend_Registry::set('config', $config);
        return $config;
    } 
    
}