<?php

class User_Bootstrap extends Zend_Application_Module_Bootstrap
{
    /**
     * This allows for adding resources with configuration options
     */
    protected function _initPlugins()
    {
        $bootstrap = $this->getApplication();
        $bootstrap->bootstrap('frontcontroller');
        $front = $bootstrap->getResource('frontcontroller');
        $front->registerPlugin(new User_Plugin_Menu());
    }
    
    /**
     * Setup access control lists for the application.
     *
     * Currently it has three roles: guest, developer and manager. With this
     * it setups up a logs:index and default:index resource along with
     * permissions on those resources.
     * @link http://framework.zend.com/manual/en/zend.acl.html
     * @return Zend_Acl
     */
    protected function _initAcls()
    {
        $acl = new Zend_Acl();
        $acl->addRole(new Zend_Acl_Role('guest'))
            ->addRole(new Zend_Acl_Role('client', 'guest'))
            ->addRole(new Zend_Acl_Role('administrator', 'client'));

        $moduleResource = new Zend_Acl_Resource('logs');
        $acl->add($moduleResource)
            ->add(new Zend_Acl_Resource('reports:view'), $moduleResource)
            ->add(new Zend_Acl_Resource('reports:add'), $moduleResource)
            ->add(new Zend_Acl_Resource('orders:add'), $moduleResource)
            ->add(new Zend_Acl_Resource('invoices:add'), $moduleResource)
            ->add(new Zend_Acl_Resource('history:add'), $moduleResource)
            ->add(new Zend_Acl_Resource('financials:view'), $moduleResource)
            ->add(new Zend_Acl_Resource('accounts:view'), $moduleResource)
            ->add(new Zend_Acl_Resource('default:index'), $moduleResource)
            ->add(new Zend_Acl_Resource('user:index'), $moduleResource);

        $acl->allow(
            array('client'), 'reports:view',
            array('competitor', 'on-page', 'link', 'rankings')
        );
        
        $acl->allow(
            array('client'), 'financials:view',
            array('invoices', 'orders')
        );
        
        $acl->allow(
            array('client'), 'accounts:view',
            array('history')
        );

        $acl->allow(
            array('administrator'), 
            array(
                'reports:view',
                'reports:add',
                'orders:add',
                'invoices:add',
                'history:add',
                'financials:view',
                'accounts:view'
            )
        );

        $acl->allow(null, 'default:index');
        $acl->allow('client', 'user:index');
        $acl->allow('administrator', 'user:index');
        
        Zend_Registry::set('acl', $acl);

        $front = Zend_Controller_Front::getInstance();

        // add the auth setup plugin
        $front->registerPlugin(
            new User_Plugin_Acl()
        );

        return $acl;
    }
    
    /**
     * Setup the application navigation.
     *
     * Covers support for menus, links, breadcrumbs and is translation enabled
     * @link http://framework.zend.com/manual/en/zend.navigation.html
     * @see _buildNavigationObject()
     */
    protected function _initNavigation()
    {
        $bootstrap = $this->getApplication();
        $bootstrap->bootstrap('layout');        
        $layout = $bootstrap->getResource('layout');
        $view = $layout->getView();
        $config = new Zend_Config_Xml(APPLICATION_PATH . '/configs/navigation.xml', 'nav');
        $acl = Zend_Registry::get('acl');
        $navigation = new Zend_Navigation($config);        
        $view->navigation($navigation);        
        
        Zend_Registry::set('Zend_Navigation', $navigation);        
        Zend_View_Helper_Navigation_HelperAbstract::setDefaultAcl($acl);
        Zend_View_Helper_Navigation_HelperAbstract::setDefaultRole('guest');

        return $navigation;
    }
    
}
